@@ -14,5 +14,6 @@ Submodules
 from . import hdf_utils, hdf_io
 from .nsi_reader import NSIDReader
 from .hdf_io import *
+from .hdf_utils import make_nexus_compatible
 
-__all__ = ['hdf_utils', 'hdf_io', 'NSIDReader']
\ No newline at end of file
+__all__ = ['hdf_utils', 'hdf_io', 'NSIDReader', 'make_nexus_compatible']
\ No newline at end of file
